WindowExtWayland

Trait WindowExtWayland 

pub trait WindowExtWayland {
    // Required method
    fn xdg_toplevel(&self) -> Option<NonNull<c_void>>;
}
Additional methods on Window that are specific to Wayland.

Required Methods

fn xdg_toplevel(&self) -> Option<NonNull<c_void>>

Returns xdg_toplevel of the window or None if the window is X11 window.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors